#
# spec file for package gap-orb
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gap-orb
Version:        5.0.0
Release:        2.1
Summary:        GAP: Methods to enumerate Orbits
License:        GPL-3.0-or-later
Group:          Productivity/Scientific/Math
URL:            https://gap-packages.github.io/orb
#Git-Clone:	https://github.com/gap-packages/orb
Source:         https://github.com/gap-packages/orb/releases/download/v%version/orb-%version.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gap-devel >= 4.12
BuildRequires:  gap-rpm-devel
BuildRequires:  gmp-devel
BuildRequires:  libtool
Requires:       gap-core >= 4.12
Suggests:       gap-io >= 3.3

%description
The orb package is about enumerating orbits in various ways.

%prep
%autosetup -n orb-%version

%build
./configure --with-gaproot="%gapdir"
%make_build

%install
%gappkg_simple_install
rm -Rf "%buildroot/$moddir/src"

%files -f %name.files

%changelog
* Thu Feb 27 2025 Jan Engelhardt <jengelh@inai.de>
- Make specfile conform to POSIX sh
* Wed Jan 22 2025 Jan Engelhardt <jengelh@inai.de>
- Update to release 5.0.0
  * Remove legacy APIs `InitHT`, `NewHT`, `AddHT`, `ValueHT`,
    `GrowHT`. Instead use `HTCreate`, `HTAdd`, `HTValue`,
    `HTDelete` and `HTUpdate`.
* Fri Jan  3 2025 Jan Engelhardt <jengelh@inai.de>
- Update to release 4.9.2
  * Prepare for a future GAP version introducing PreImagesElmNC
    and PreImagesRepresentativeNC
* Tue Aug 27 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 4.9.1
  * More hash functions now detect invalid input and return
    `fail` instead of returning garbage (like hashes of random
    memory blocks, or the constant 0) or even crashing.
* Sun Feb 12 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 4.9.0
  * Validate the output of hash functions in the C implementation,
    and report bad values as errors, instead of crashing or corrupting
    data.
* Thu Nov 15 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 4.8.1
  * Deal with hash functions returning 'fail', or any other
    non-integer (instead of crashing or doing other random things)
  * Change several ORB_HashFunction to return fail if necessary
* Mon Dec 25 2017 jengelh@inai.de
- Update to new upstream release 4.8.0
  * Renamed the IsClosed filter to IsClosedOrbit, and added a new
    operation IsClosed which simply returns the value of the
    IsClosedOrbit filter. This allows other packages do also use
    the name IsClosed.
  * Fix hash tables with initial size <= 5 not growing correctly
  * Fix ORB_HashFunctionModWrapper
  * Fix bug in HTGrow causing it to never call
    ORB_HashFunctionModWrapper
  * Ensure compatibility with GAP 4.9
* Wed Jun  8 2016 jengelh@inai.de
- Update to new upstream release 4.7.6
  * Move MappingPermListList C implementation from orb to the GAP
  kernel
  * Fix regression which prevent orb from being used without
  compilation
  * Some changes to the C code for compatibility with HPC-GAP
* Sat Mar 12 2016 jengelh@inai.de
- Update to new upstream release 4.7.5
  * Show an error when the user tries to compute orbits of objects
  for which no ChooseHashFunction method is available. Previously,
  it would fall back to a "trivial" hash function, which lead to
  worst-case performance.
  * Remove Jenkins hash in favor of the Murmur hash built into GAP
  * Document that MakeSchreierTreeShallow only works for orbits with
  log.
* Fri Dec 12 2014 jengelh@inai.de
- Update to new upstream release 4.7.3
  * Use hash functions for transformations and partial permutations
  provided by newer GAP versions instead of our own. This way, if
  the internal representation for these objects changes (as has
  recently happened), we stay compatible (see issue #3).
  * Fix bug were orb logs were not properly updated if the
  enumeration stopped early (see issues #4 and #5).
  * Fix bug caused by orbits with seeds (see issue #5).
  * Fix error in Memory() method for orbit-by-suborbit setup objects.
  * Fix a missing variable initialization, which could cause
  Enumerate (and hence anything using it, such as
  FindShortGeneratorsOfSubgroup) to run into an error.
- Remove orb-install.diff (fixed upstream)
* Fri May 10 2013 jengelh@inai.de
- Split orb (version 4.6) off the gap RPM package
